diff --git a/src/os/unix/ngx_process.c b/src/os/unix/ngx_process.c
--- a/src/os/unix/ngx_process.c
+++ b/src/os/unix/ngx_process.c
@@ -13,13 +13,14 @@
 typedef struct {
      int     signo;
      char   *signame;
-     void  (*handler)(int signo);
+     void  (*handler)(int signo, siginfo_t *info, void *context);
 } ngx_signal_t;
 
 
 
 static void ngx_execute_proc(ngx_cycle_t *cycle, void *data);
-static void ngx_signal_handler(int signo);
+static void ngx_signal_handler(int signo, siginfo_t *info, void *context);
+static void ngx_ignore_signal_handler(int signo, siginfo_t *info, void *context);
 static void ngx_process_get_status(void);
 
 
@@ -66,7 +67,7 @@
 
     { SIGCHLD, "SIGCHLD", ngx_signal_handler },
 
-    { SIGPIPE, "SIGPIPE, SIG_IGN", SIG_IGN },
+    { SIGPIPE, "SIGPIPE, SIG_IGN", ngx_ignore_signal_handler },
 
     { 0, NULL, NULL }
 };
@@ -265,7 +266,8 @@
 
     for (sig = signals; sig->signo != 0; sig++) {
         ngx_memzero(&sa, sizeof(struct sigaction));
-        sa.sa_handler = sig->handler;
+        sa.sa_flags = SA_SIGINFO;
+        sa.sa_sigaction = sig->handler;
         sigemptyset(&sa.sa_mask);
         if (sigaction(sig->signo, &sa, NULL) == -1) {
             ngx_log_error(NGX_LOG_EMERG, log, ngx_errno,
@@ -279,7 +281,7 @@
 
 
 void
-ngx_signal_handler(int signo)
+ngx_signal_handler(int signo, siginfo_t *info, void *context)
 {
     char            *action;
     ngx_int_t        ignore;
@@ -397,7 +399,7 @@
     }
 
     ngx_log_error(NGX_LOG_NOTICE, ngx_cycle->log, 0,
-                  "signal %d (%s) received%s", signo, sig->signame, action);
+                  "signal %d (%s) received%s from %d", signo, sig->signame, action, info->si_pid);
 
     if (ignore) {
         ngx_log_error(NGX_LOG_CRIT, ngx_cycle->log, 0,
@@ -411,6 +413,11 @@
     }
 
     ngx_set_errno(err);
+}
+
+void
+ngx_ignore_signal_handler(int signo, siginfo_t *info, void *context)
+{
 }
 
 
